@@ -11,9 +11,9 @@ def classref(value, short=True):
     return value
 
     if not inspect.isclass(value):
-        return ":class:%s" % value
+        return f":class:{value}"
     tilde = "~" if short else ""
-    return ":class:`%sgitlab.objects.%s`" % (tilde, value.__name__)
+    return f":class:`{tilde}gitlab.objects.{value.__name__}`"
 
 
 def setup(app):
@@ -48,9 +48,7 @@ class GitlabDocstring(GoogleDocstring):
     def __init__(
         self, docstring, config=None, app=None, what="", name="", obj=None, options=None
     ):
-        super(GitlabDocstring, self).__init__(
-            docstring, config, app, what, name, obj, options
-        )
+        super().__init__(docstring, config, app, what, name, obj, options)
 
         if name.startswith("gitlab.v4.objects") and name.endswith("Manager"):
             self._parsed_lines.extend(self._build_doc("manager_tmpl.j2", cls=self._obj))
