@@ -1,27 +1,10 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (C) 2013-2017 Gauvain Pocentek <gauvain@pocentek.net>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 import copy
 import importlib
 import json
 import pprint
 import textwrap
 from types import ModuleType
-from typing import Any, Dict, Iterable, Optional, Type, Union
+from typing import Any, Dict, Iterable, Optional, Type, TYPE_CHECKING, Union
 
 import gitlab
 from gitlab import types as g_types
@@ -245,14 +228,20 @@ class RESTObject:
         """Returns the id of the resource."""
         if self._id_attr is None or not hasattr(self, self._id_attr):
             return None
-        return getattr(self, self._id_attr)
+        id_val = getattr(self, self._id_attr)
+        if TYPE_CHECKING:
+            assert id_val is None or isinstance(id_val, (int, str))
+        return id_val
 
     @property
     def _repr_value(self) -> Optional[str]:
         """Safely returns the human-readable resource name if present."""
         if self._repr_attr is None or not hasattr(self, self._repr_attr):
             return None
-        return getattr(self, self._repr_attr)
+        repr_val = getattr(self, self._repr_attr)
+        if TYPE_CHECKING:
+            assert isinstance(repr_val, str)
+        return repr_val
 
     @property
     def encoded_id(self) -> Optional[Union[int, str]]:
