@@ -54,6 +54,39 @@ class SearchScope(GitlabEnum):
     PROJECT_NOTES: str = "notes"
 
 
+# https://docs.gitlab.com/ee/api/merge_requests.html#merge-status
+class DetailedMergeStatus(GitlabEnum):
+    # possible values for the detailed_merge_status field of Merge Requests
+    BLOCKED_STATUS: str = "blocked_status"
+    BROKEN_STATUS: str = "broken_status"
+    CHECKING: str = "checking"
+    UNCHECKED: str = "unchecked"
+    CI_MUST_PASS: str = "ci_must_pass"
+    CI_STILL_RUNNING: str = "ci_still_running"
+    DISCUSSIONS_NOT_RESOLVED: str = "discussions_not_resolved"
+    DRAFT_STATUS: str = "draft_status"
+    EXTERNAL_STATUS_CHECKS: str = "external_status_checks"
+    MERGEABLE: str = "mergeable"
+    NOT_APPROVED: str = "not_approved"
+    NOT_OPEN: str = "not_open"
+    POLICIES_DENIED: str = "policies_denied"
+
+
+# https://docs.gitlab.com/ee/api/pipelines.html
+class PipelineStatus(GitlabEnum):
+    CREATED: str = "created"
+    WAITING_FOR_RESOURCE: str = "waiting_for_resource"
+    PREPARING: str = "preparing"
+    PENDING: str = "pending"
+    RUNNING: str = "running"
+    SUCCESS: str = "success"
+    FAILED: str = "failed"
+    CANCELED: str = "canceled"
+    SKIPPED: str = "skipped"
+    MANUAL: str = "manual"
+    SCHEDULED: str = "scheduled"
+
+
 DEFAULT_URL: str = "https://gitlab.com"
 
 NO_ACCESS = AccessLevel.NO_ACCESS.value
