@@ -2,6 +2,7 @@
 GitLab API:
 https://docs.gitlab.com/ee/api/job_artifacts.html
 """
+
 from typing import Any, Callable, Iterator, Optional, TYPE_CHECKING, Union
 
 import requests
@@ -25,30 +26,6 @@ class ProjectArtifactManager(RESTManager):
     _path = "/projects/{project_id}/jobs/artifacts"
     _from_parent_attrs = {"project_id": "id"}
 
-    @cli.register_custom_action(
-        "Project", ("ref_name", "job"), ("job_token",), custom_action="artifacts"
-    )
-    def __call__(
-        self,
-        *args: Any,
-        **kwargs: Any,
-    ) -> Optional[bytes]:
-        utils.warn(
-            message=(
-                "The project.artifacts() method is deprecated and will be removed in a "
-                "future version. Use project.artifacts.download() instead.\n"
-            ),
-            category=DeprecationWarning,
-        )
-        data = self.download(
-            *args,
-            **kwargs,
-        )
-        if TYPE_CHECKING:
-            assert data is not None
-            assert isinstance(data, bytes)
-        return data
-
     @exc.on_http_error(exc.GitlabDeleteError)
     def delete(self, **kwargs: Any) -> None:
         """Delete the project's artifacts on the server.
@@ -67,7 +44,9 @@ class ProjectArtifactManager(RESTManager):
         self.gitlab.http_delete(path, **kwargs)
 
     @cli.register_custom_action(
-        "ProjectArtifactManager", ("ref_name", "job"), ("job_token",)
+        cls_names="ProjectArtifactManager",
+        required=("ref_name", "job"),
+        optional=("job_token",),
     )
     @exc.on_http_error(exc.GitlabGetError)
     def download(
@@ -85,7 +64,7 @@ class ProjectArtifactManager(RESTManager):
 
         Args:
             ref_name: Branch or tag name in repository. HEAD or SHA references
-            are not supported.
+                are not supported.
             job: The name of the job.
             job_token: Job token for multi-project pipeline triggers.
             streamed: If True the data will be processed by chunks of
@@ -116,7 +95,8 @@ class ProjectArtifactManager(RESTManager):
         )
 
     @cli.register_custom_action(
-        "ProjectArtifactManager", ("ref_name", "artifact_path", "job")
+        cls_names="ProjectArtifactManager",
+        required=("ref_name", "artifact_path", "job"),
     )
     @exc.on_http_error(exc.GitlabGetError)
     def raw(
