@@ -40,6 +40,7 @@ class ProjectFile(SaveMixin, ObjectDeleteMixin, RESTObject):
     commit_message: str
     file_path: str
     manager: "ProjectFileManager"
+    content: str  # since the `decode()` method uses `self.content`
 
     def decode(self) -> bytes:
         """Returns the decoded content of the file.
@@ -108,7 +109,9 @@ class ProjectFileManager(GetMixin, CreateMixin, UpdateMixin, DeleteMixin, RESTMa
         optional=("encoding", "author_email", "author_name"),
     )
 
-    @cli.register_custom_action("ProjectFileManager", ("file_path", "ref"))
+    @cli.register_custom_action(
+        cls_names="ProjectFileManager", required=("file_path", "ref")
+    )
     # NOTE(jlvillal): Signature doesn't match UpdateMixin.update() so ignore
     # type error
     def get(  # type: ignore
@@ -131,9 +134,9 @@ class ProjectFileManager(GetMixin, CreateMixin, UpdateMixin, DeleteMixin, RESTMa
         return cast(ProjectFile, GetMixin.get(self, file_path, ref=ref, **kwargs))
 
     @cli.register_custom_action(
-        "ProjectFileManager",
-        ("file_path", "branch", "content", "commit_message"),
-        ("encoding", "author_email", "author_name"),
+        cls_names="ProjectFileManager",
+        required=("file_path", "branch", "content", "commit_message"),
+        optional=("encoding", "author_email", "author_name"),
     )
     @exc.on_http_error(exc.GitlabCreateError)
     def create(
@@ -198,7 +201,8 @@ class ProjectFileManager(GetMixin, CreateMixin, UpdateMixin, DeleteMixin, RESTMa
         return result
 
     @cli.register_custom_action(
-        "ProjectFileManager", ("file_path", "branch", "commit_message")
+        cls_names="ProjectFileManager",
+        required=("file_path", "branch", "commit_message"),
     )
     @exc.on_http_error(exc.GitlabDeleteError)
     # NOTE(jlvillal): Signature doesn't match DeleteMixin.delete() so ignore
@@ -223,12 +227,15 @@ class ProjectFileManager(GetMixin, CreateMixin, UpdateMixin, DeleteMixin, RESTMa
         data = {"branch": branch, "commit_message": commit_message}
         self.gitlab.http_delete(path, query_data=data, **kwargs)
 
-    @cli.register_custom_action("ProjectFileManager", ("file_path", "ref"))
+    @cli.register_custom_action(
+        cls_names="ProjectFileManager",
+        required=("file_path",),
+    )
     @exc.on_http_error(exc.GitlabGetError)
     def raw(
         self,
         file_path: str,
-        ref: str,
+        ref: Optional[str] = None,
         streamed: bool = False,
         action: Optional[Callable[..., Any]] = None,
         chunk_size: int = 1024,
@@ -239,16 +246,16 @@ class ProjectFileManager(GetMixin, CreateMixin, UpdateMixin, DeleteMixin, RESTMa
         """Return the content of a file for a commit.
 
         Args:
-            ref: ID of the commit
             file_path: Path of the file to return
+            ref: ID of the commit
             streamed: If True the data will be processed by chunks of
                 `chunk_size` and each chunk is passed to `action` for
                 treatment
-            iterator: If True directly return the underlying response
-                iterator
-            action: Callable responsible of dealing with chunk of
+            action: Callable responsible for dealing with each chunk of
                 data
             chunk_size: Size of each chunk
+            iterator: If True directly return the underlying response
+                iterator
             **kwargs: Extra options to send to the server (e.g. sudo)
 
         Raises:
@@ -260,7 +267,10 @@ class ProjectFileManager(GetMixin, CreateMixin, UpdateMixin, DeleteMixin, RESTMa
         """
         file_path = utils.EncodedId(file_path)
         path = f"{self.path}/{file_path}/raw"
-        query_data = {"ref": ref}
+        if ref is not None:
+            query_data = {"ref": ref}
+        else:
+            query_data = None
         result = self.gitlab.http_get(
             path, query_data=query_data, streamed=streamed, raw=True, **kwargs
         )
@@ -270,7 +280,9 @@ class ProjectFileManager(GetMixin, CreateMixin, UpdateMixin, DeleteMixin, RESTMa
             result, streamed, action, chunk_size, iterator=iterator
         )
 
-    @cli.register_custom_action("ProjectFileManager", ("file_path", "ref"))
+    @cli.register_custom_action(
+        cls_names="ProjectFileManager", required=("file_path", "ref")
+    )
     @exc.on_http_error(exc.GitlabListError)
     def blame(self, file_path: str, ref: str, **kwargs: Any) -> List[Dict[str, Any]]:
         """Return the content of a file for a commit.
