@@ -2,6 +2,8 @@
 GitLab API:
 https://docs.gitlab.com/ee/api/projects.html
 """
+
+import io
 from typing import (
     Any,
     Callable,
@@ -23,12 +25,14 @@ from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import (
     CreateMixin,
     CRUDMixin,
+    DeleteMixin,
     GetWithoutIdMixin,
     ListMixin,
     ObjectDeleteMixin,
     RefreshMixin,
     SaveMixin,
     UpdateMixin,
+    UploadMixin,
 )
 from gitlab.types import RequiredOptional
 
@@ -39,6 +43,7 @@ from .badges import ProjectBadgeManager  # noqa: F401
 from .boards import ProjectBoardManager  # noqa: F401
 from .branches import ProjectBranchManager, ProjectProtectedBranchManager  # noqa: F401
 from .ci_lint import ProjectCiLintManager  # noqa: F401
+from .cluster_agents import ProjectClusterAgentManager  # noqa: F401
 from .clusters import ProjectClusterManager  # noqa: F401
 from .commits import ProjectCommitManager  # noqa: F401
 from .container_registry import ProjectRegistryRepositoryManager  # noqa: F401
@@ -57,7 +62,8 @@ from .hooks import ProjectHookManager  # noqa: F401
 from .integrations import ProjectIntegrationManager, ProjectServiceManager  # noqa: F401
 from .invitations import ProjectInvitationManager  # noqa: F401
 from .issues import ProjectIssueManager  # noqa: F401
-from .iterations import GroupIterationManager  # noqa: F401
+from .iterations import ProjectIterationManager  # noqa: F401
+from .job_token_scope import ProjectJobTokenScopeManager  # noqa: F401
 from .jobs import ProjectJobManager  # noqa: F401
 from .labels import ProjectLabelManager  # noqa: F401
 from .members import ProjectMemberAllManager, ProjectMemberManager  # noqa: F401
@@ -70,6 +76,7 @@ from .merge_trains import ProjectMergeTrainManager  # noqa: F401
 from .milestones import ProjectMilestoneManager  # noqa: F401
 from .notes import ProjectNoteManager  # noqa: F401
 from .notification_settings import ProjectNotificationSettingsManager  # noqa: F401
+from .package_protection_rules import ProjectPackageProtectionRuleManager
 from .packages import GenericPackageManager, ProjectPackageManager  # noqa: F401
 from .pages import ProjectPagesDomainManager  # noqa: F401
 from .pipelines import (  # noqa: F401
@@ -79,8 +86,12 @@ from .pipelines import (  # noqa: F401
 )
 from .project_access_tokens import ProjectAccessTokenManager  # noqa: F401
 from .push_rules import ProjectPushRulesManager  # noqa: F401
+from .registry_protection_rules import (  # noqa: F401
+    ProjectRegistryProtectionRuleManager,
+)
 from .releases import ProjectReleaseManager  # noqa: F401
 from .repositories import RepositoryMixin
+from .resource_groups import ProjectResourceGroupManager
 from .runners import ProjectRunnerManager  # noqa: F401
 from .secure_files import ProjectSecureFileManager  # noqa: F401
 from .snippets import ProjectSnippetManager  # noqa: F401
@@ -155,8 +166,11 @@ class ProjectGroupManager(ListMixin, RESTManager):
     _types = {"skip_groups": types.ArrayAttribute}
 
 
-class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTObject):
+class Project(
+    RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, UploadMixin, RESTObject
+):
     _repr_attr = "path_with_namespace"
+    _upload_path = "/projects/{id}/uploads"
 
     access_tokens: ProjectAccessTokenManager
     accessrequests: ProjectAccessRequestManager
@@ -170,6 +184,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
     branches: ProjectBranchManager
     ci_lint: ProjectCiLintManager
     clusters: ProjectClusterManager
+    cluster_agents: ProjectClusterAgentManager
     commits: ProjectCommitManager
     customattributes: ProjectCustomAttributeManager
     deployments: ProjectDeploymentManager
@@ -187,8 +202,9 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
     invitations: ProjectInvitationManager
     issues: ProjectIssueManager
     issues_statistics: ProjectIssuesStatisticsManager
-    iterations: GroupIterationManager
+    iterations: ProjectIterationManager
     jobs: ProjectJobManager
+    job_token_scope: ProjectJobTokenScopeManager
     keys: ProjectKeyManager
     labels: ProjectLabelManager
     members: ProjectMemberManager
@@ -199,6 +215,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
     notes: ProjectNoteManager
     notificationsettings: ProjectNotificationSettingsManager
     packages: ProjectPackageManager
+    package_protection_rules: ProjectPackageProtectionRuleManager
     pagesdomains: ProjectPagesDomainManager
     pipelines: ProjectPipelineManager
     pipelineschedules: ProjectPipelineScheduleManager
@@ -206,7 +223,9 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
     protectedbranches: ProjectProtectedBranchManager
     protectedtags: ProjectProtectedTagManager
     pushrules: ProjectPushRulesManager
+    registry_protection_rules: ProjectRegistryProtectionRuleManager
     releases: ProjectReleaseManager
+    resource_groups: ProjectResourceGroupManager
     remote_mirrors: "ProjectRemoteMirrorManager"
     repositories: ProjectRegistryRepositoryManager
     runners: ProjectRunnerManager
@@ -220,7 +239,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
     variables: ProjectVariableManager
     wikis: ProjectWikiManager
 
-    @cli.register_custom_action("Project", ("forked_from_id",))
+    @cli.register_custom_action(cls_names="Project", required=("forked_from_id",))
     @exc.on_http_error(exc.GitlabCreateError)
     def create_fork_relation(self, forked_from_id: int, **kwargs: Any) -> None:
         """Create a forked from/to relation between existing projects.
@@ -236,7 +255,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
         path = f"/projects/{self.encoded_id}/fork/{forked_from_id}"
         self.manager.gitlab.http_post(path, **kwargs)
 
-    @cli.register_custom_action("Project")
+    @cli.register_custom_action(cls_names="Project")
     @exc.on_http_error(exc.GitlabDeleteError)
     def delete_fork_relation(self, **kwargs: Any) -> None:
         """Delete a forked relation between existing projects.
@@ -251,7 +270,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
         path = f"/projects/{self.encoded_id}/fork"
         self.manager.gitlab.http_delete(path, **kwargs)
 
-    @cli.register_custom_action("Project")
+    @cli.register_custom_action(cls_names="Project")
     @exc.on_http_error(exc.GitlabGetError)
     def languages(self, **kwargs: Any) -> Union[Dict[str, Any], requests.Response]:
         """Get languages used in the project with percentage value.
@@ -266,7 +285,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
         path = f"/projects/{self.encoded_id}/languages"
         return self.manager.gitlab.http_get(path, **kwargs)
 
-    @cli.register_custom_action("Project")
+    @cli.register_custom_action(cls_names="Project")
     @exc.on_http_error(exc.GitlabCreateError)
     def star(self, **kwargs: Any) -> None:
         """Star a project.
@@ -284,7 +303,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
             assert isinstance(server_data, dict)
         self._update_attrs(server_data)
 
-    @cli.register_custom_action("Project")
+    @cli.register_custom_action(cls_names="Project")
     @exc.on_http_error(exc.GitlabDeleteError)
     def unstar(self, **kwargs: Any) -> None:
         """Unstar a project.
@@ -302,7 +321,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
             assert isinstance(server_data, dict)
         self._update_attrs(server_data)
 
-    @cli.register_custom_action("Project")
+    @cli.register_custom_action(cls_names="Project")
     @exc.on_http_error(exc.GitlabCreateError)
     def archive(self, **kwargs: Any) -> None:
         """Archive a project.
@@ -320,7 +339,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
             assert isinstance(server_data, dict)
         self._update_attrs(server_data)
 
-    @cli.register_custom_action("Project")
+    @cli.register_custom_action(cls_names="Project")
     @exc.on_http_error(exc.GitlabDeleteError)
     def unarchive(self, **kwargs: Any) -> None:
         """Unarchive a project.
@@ -339,7 +358,9 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
         self._update_attrs(server_data)
 
     @cli.register_custom_action(
-        "Project", ("group_id", "group_access"), ("expires_at",)
+        cls_names="Project",
+        required=("group_id", "group_access"),
+        optional=("expires_at",),
     )
     @exc.on_http_error(exc.GitlabCreateError)
     def share(
@@ -368,7 +389,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
         }
         self.manager.gitlab.http_post(path, post_data=data, **kwargs)
 
-    @cli.register_custom_action("Project", ("group_id",))
+    @cli.register_custom_action(cls_names="Project", required=("group_id",))
     @exc.on_http_error(exc.GitlabDeleteError)
     def unshare(self, group_id: int, **kwargs: Any) -> None:
         """Delete a shared project link within a group.
@@ -385,7 +406,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
         self.manager.gitlab.http_delete(path, **kwargs)
 
     # variables not supported in CLI
-    @cli.register_custom_action("Project", ("ref", "token"))
+    @cli.register_custom_action(cls_names="Project", required=("ref", "token"))
     @exc.on_http_error(exc.GitlabCreateError)
     def trigger_pipeline(
         self,
@@ -416,7 +437,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
             assert isinstance(attrs, dict)
         return ProjectPipeline(self.pipelines, attrs)
 
-    @cli.register_custom_action("Project")
+    @cli.register_custom_action(cls_names="Project")
     @exc.on_http_error(exc.GitlabHousekeepingError)
     def housekeeping(self, **kwargs: Any) -> None:
         """Start the housekeeping task.
@@ -432,60 +453,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
         path = f"/projects/{self.encoded_id}/housekeeping"
         self.manager.gitlab.http_post(path, **kwargs)
 
-    # see #56 - add file attachment features
-    @cli.register_custom_action("Project", ("filename", "filepath"))
-    @exc.on_http_error(exc.GitlabUploadError)
-    def upload(
-        self,
-        filename: str,
-        filedata: Optional[bytes] = None,
-        filepath: Optional[str] = None,
-        **kwargs: Any,
-    ) -> Dict[str, Any]:
-        """Upload the specified file into the project.
-
-        .. note::
-
-            Either ``filedata`` or ``filepath`` *MUST* be specified.
-
-        Args:
-            filename: The name of the file being uploaded
-            filedata: The raw data of the file being uploaded
-            filepath: The path to a local file to upload (optional)
-
-        Raises:
-            GitlabConnectionError: If the server cannot be reached
-            GitlabUploadError: If the file upload fails
-            GitlabUploadError: If ``filedata`` and ``filepath`` are not
-                specified
-            GitlabUploadError: If both ``filedata`` and ``filepath`` are
-                specified
-
-        Returns:
-            A ``dict`` with the keys:
-                * ``alt`` - The alternate text for the upload
-                * ``url`` - The direct url to the uploaded file
-                * ``markdown`` - Markdown for the uploaded file
-        """
-        if filepath is None and filedata is None:
-            raise exc.GitlabUploadError("No file contents or path specified")
-
-        if filedata is not None and filepath is not None:
-            raise exc.GitlabUploadError("File contents and file path specified")
-
-        if filepath is not None:
-            with open(filepath, "rb") as f:
-                filedata = f.read()
-
-        url = f"/projects/{self.encoded_id}/uploads"
-        file_info = {"file": (filename, filedata)}
-        data = self.manager.gitlab.http_post(url, files=file_info, **kwargs)
-
-        if TYPE_CHECKING:
-            assert isinstance(data, dict)
-        return {"alt": data["alt"], "url": data["url"], "markdown": data["markdown"]}
-
-    @cli.register_custom_action("Project")
+    @cli.register_custom_action(cls_names="Project")
     @exc.on_http_error(exc.GitlabRestoreError)
     def restore(self, **kwargs: Any) -> None:
         """Restore a project marked for deletion.
@@ -500,7 +468,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
         path = f"/projects/{self.encoded_id}/restore"
         self.manager.gitlab.http_post(path, **kwargs)
 
-    @cli.register_custom_action("Project", optional=("wiki",))
+    @cli.register_custom_action(cls_names="Project", optional=("wiki",))
     @exc.on_http_error(exc.GitlabGetError)
     def snapshot(
         self,
@@ -543,7 +511,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
             result, streamed, action, chunk_size, iterator=iterator
         )
 
-    @cli.register_custom_action("Project", ("scope", "search"))
+    @cli.register_custom_action(cls_names="Project", required=("scope", "search"))
     @exc.on_http_error(exc.GitlabSearchError)
     def search(
         self, scope: str, search: str, **kwargs: Any
@@ -566,7 +534,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
         path = f"/projects/{self.encoded_id}/search"
         return self.manager.gitlab.http_list(path, query_data=data, **kwargs)
 
-    @cli.register_custom_action("Project")
+    @cli.register_custom_action(cls_names="Project")
     @exc.on_http_error(exc.GitlabCreateError)
     def mirror_pull(self, **kwargs: Any) -> None:
         """Start the pull mirroring process for the project.
@@ -581,7 +549,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
         path = f"/projects/{self.encoded_id}/mirror/pull"
         self.manager.gitlab.http_post(path, **kwargs)
 
-    @cli.register_custom_action("Project")
+    @cli.register_custom_action(cls_names="Project")
     @exc.on_http_error(exc.GitlabGetError)
     def mirror_pull_details(self, **kwargs: Any) -> Dict[str, Any]:
         """Get a project's pull mirror details.
@@ -604,7 +572,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
             assert isinstance(result, dict)
         return result
 
-    @cli.register_custom_action("Project", ("to_namespace",))
+    @cli.register_custom_action(cls_names="Project", required=("to_namespace",))
     @exc.on_http_error(exc.GitlabTransferProjectError)
     def transfer(self, to_namespace: Union[int, str], **kwargs: Any) -> None:
         """Transfer a project to the given namespace ID
@@ -623,37 +591,6 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
             path, post_data={"namespace": to_namespace}, **kwargs
         )
 
-    @cli.register_custom_action("Project", ("to_namespace",))
-    def transfer_project(self, *args: Any, **kwargs: Any) -> None:
-        utils.warn(
-            message=(
-                "The project.transfer_project() method is deprecated and will be "
-                "removed in a future version. Use project.transfer() instead."
-            ),
-            category=DeprecationWarning,
-        )
-        return self.transfer(*args, **kwargs)
-
-    @cli.register_custom_action("Project", ("ref_name", "artifact_path", "job"))
-    @exc.on_http_error(exc.GitlabGetError)
-    def artifact(
-        self,
-        *args: Any,
-        **kwargs: Any,
-    ) -> Optional[bytes]:
-        utils.warn(
-            message=(
-                "The project.artifact() method is deprecated and will be "
-                "removed in a future version. Use project.artifacts.raw() instead."
-            ),
-            category=DeprecationWarning,
-        )
-        data = self.artifacts.raw(*args, **kwargs)
-        if TYPE_CHECKING:
-            assert data is not None
-            assert isinstance(data, bytes)
-        return data
-
 
 class ProjectManager(CRUDMixin, RESTManager):
     _path = "/projects"
@@ -665,6 +602,7 @@ class ProjectManager(CRUDMixin, RESTManager):
             "name",
             "path",
             "allow_merge_on_skipped_pipeline",
+            "only_allow_merge_if_all_status_checks_passed",
             "analytics_access_level",
             "approvals_before_merge",
             "auto_cancel_pending_pipelines",
@@ -678,6 +616,7 @@ class ProjectManager(CRUDMixin, RESTManager):
             "builds_access_level",
             "ci_config_path",
             "container_expiration_policy_attributes",
+            "container_registry_access_level",
             "container_registry_enabled",
             "default_branch",
             "description",
@@ -706,11 +645,17 @@ class ProjectManager(CRUDMixin, RESTManager):
             "requirements_access_level",
             "printing_merge_request_link_enabled",
             "public_builds",
+            "releases_access_level",
+            "environments_access_level",
+            "feature_flags_access_level",
+            "infrastructure_access_level",
+            "monitor_access_level",
             "remove_source_branch_after_merge",
             "repository_access_level",
             "repository_storage",
             "request_access_enabled",
             "resolve_outdated_diff_discussions",
+            "security_and_compliance_access_level",
             "shared_runners_enabled",
             "show_default_award_emojis",
             "snippets_access_level",
@@ -731,6 +676,7 @@ class ProjectManager(CRUDMixin, RESTManager):
     _update_attrs = RequiredOptional(
         optional=(
             "allow_merge_on_skipped_pipeline",
+            "only_allow_merge_if_all_status_checks_passed",
             "analytics_access_level",
             "approvals_before_merge",
             "auto_cancel_pending_pipelines",
@@ -745,22 +691,31 @@ class ProjectManager(CRUDMixin, RESTManager):
             "ci_config_path",
             "ci_default_git_depth",
             "ci_forward_deployment_enabled",
+            "ci_allow_fork_pipelines_to_run_in_parent_project",
+            "ci_separated_caches",
             "container_expiration_policy_attributes",
+            "container_registry_access_level",
             "container_registry_enabled",
             "default_branch",
             "description",
             "emails_disabled",
+            "enforce_auth_checks_on_uploads",
             "external_authorization_classification_label",
             "forking_access_level",
             "import_url",
             "issues_access_level",
             "issues_enabled",
+            "issues_template",
             "jobs_enabled",
+            "keep_latest_artifact",
             "lfs_enabled",
+            "merge_commit_template",
             "merge_method",
             "merge_pipelines_enabled",
             "merge_requests_access_level",
             "merge_requests_enabled",
+            "merge_requests_template",
+            "merge_trains_enabled",
             "mirror_overwrites_diverged_branches",
             "mirror_trigger_builds",
             "mirror_user_id",
@@ -777,16 +732,24 @@ class ProjectManager(CRUDMixin, RESTManager):
             "restrict_user_defined_variables",
             "path",
             "public_builds",
+            "releases_access_level",
+            "environments_access_level",
+            "feature_flags_access_level",
+            "infrastructure_access_level",
+            "monitor_access_level",
             "remove_source_branch_after_merge",
             "repository_access_level",
             "repository_storage",
             "request_access_enabled",
             "resolve_outdated_diff_discussions",
+            "security_and_compliance_access_level",
             "service_desk_enabled",
             "shared_runners_enabled",
             "show_default_award_emojis",
             "snippets_access_level",
             "snippets_enabled",
+            "issue_branch_template",
+            "squash_commit_template",
             "squash_option",
             "suggestion_commit_message",
             "tag_list",
@@ -794,8 +757,6 @@ class ProjectManager(CRUDMixin, RESTManager):
             "visibility",
             "wiki_access_level",
             "wiki_enabled",
-            "issues_template",
-            "merge_requests_template",
         ),
     )
     _list_filters = (
@@ -836,7 +797,7 @@ class ProjectManager(CRUDMixin, RESTManager):
     @exc.on_http_error(exc.GitlabImportError)
     def import_project(
         self,
-        file: str,
+        file: io.BufferedReader,
         path: str,
         name: Optional[str] = None,
         namespace: Optional[str] = None,
@@ -1080,6 +1041,8 @@ class ProjectManager(CRUDMixin, RESTManager):
         repo_id: int,
         target_namespace: str,
         new_name: Optional[str] = None,
+        github_hostname: Optional[str] = None,
+        optional_stages: Optional[Dict[str, bool]] = None,
         **kwargs: Any,
     ) -> Union[Dict[str, Any], requests.Response]:
         """Import a project from Github to Gitlab (schedule the import)
@@ -1100,6 +1063,9 @@ class ProjectManager(CRUDMixin, RESTManager):
             repo_id: Github repository ID
             target_namespace: Namespace to import repo into
             new_name: New repo name (Optional)
+            github_hostname: Custom GitHub Enterprise hostname.
+                Do not set for GitHub.com. (Optional)
+            optional_stages: Additional items to import. (Optional)
             **kwargs: Extra options to send to the server (e.g. sudo)
 
         Raises:
@@ -1130,9 +1096,12 @@ class ProjectManager(CRUDMixin, RESTManager):
             "personal_access_token": personal_access_token,
             "repo_id": repo_id,
             "target_namespace": target_namespace,
+            "new_name": new_name,
+            "github_hostname": github_hostname,
+            "optional_stages": optional_stages,
         }
-        if new_name:
-            data["new_name"] = new_name
+        data = utils.remove_none_from_dict(data)
+
         if (
             "timeout" not in kwargs
             or self.gitlab.timeout is None
@@ -1196,11 +1165,13 @@ class ProjectForkManager(CreateMixin, ListMixin, RESTManager):
         return cast(ProjectFork, CreateMixin.create(self, data, path=path, **kwargs))
 
 
-class ProjectRemoteMirror(SaveMixin, RESTObject):
+class ProjectRemoteMirror(ObjectDeleteMixin, SaveMixin, RESTObject):
     pass
 
 
-class ProjectRemoteMirrorManager(ListMixin, CreateMixin, UpdateMixin, RESTManager):
+class ProjectRemoteMirrorManager(
+    ListMixin, CreateMixin, UpdateMixin, DeleteMixin, RESTManager
+):
     _path = "/projects/{project_id}/remote_mirrors"
     _obj_cls = ProjectRemoteMirror
     _from_parent_attrs = {"project_id": "id"}
