@@ -24,7 +24,7 @@ __all__ = [
 class Snippet(UserAgentDetailMixin, SaveMixin, ObjectDeleteMixin, RESTObject):
     _repr_attr = "title"
 
-    @cli.register_custom_action("Snippet")
+    @cli.register_custom_action(cls_names="Snippet")
     @exc.on_http_error(exc.GitlabGetError)
     def content(
         self,
@@ -70,18 +70,55 @@ class SnippetManager(CRUDMixin, RESTManager):
     _path = "/snippets"
     _obj_cls = Snippet
     _create_attrs = RequiredOptional(
-        required=("title", "file_name", "content"), optional=("lifetime", "visibility")
+        required=("title",),
+        exclusive=("files", "file_name"),
+        optional=(
+            "description",
+            "content",
+            "visibility",
+        ),
     )
     _update_attrs = RequiredOptional(
-        optional=("title", "file_name", "content", "visibility")
+        optional=(
+            "title",
+            "files",
+            "file_name",
+            "content",
+            "visibility",
+            "description",
+        ),
     )
 
-    @cli.register_custom_action("SnippetManager")
-    def public(self, **kwargs: Any) -> Union[RESTObjectList, List[RESTObject]]:
-        """List all the public snippets.
+    @cli.register_custom_action(cls_names="SnippetManager")
+    def list_public(self, **kwargs: Any) -> Union[RESTObjectList, List[RESTObject]]:
+        """List all public snippets.
 
         Args:
-            all: If True the returned object will be a list
+            get_all: If True, return all the items, without pagination
+            per_page: Number of items to retrieve per request
+            page: ID of the page to return (starts with page 1)
+            iterator: If set to True and no pagination option is
+                defined, return a generator instead of a list
+            **kwargs: Extra options to send to the server (e.g. sudo)
+
+        Raises:
+            GitlabListError: If the list could not be retrieved
+
+        Returns:
+            The list of snippets, or a generator if `iterator` is True
+        """
+        return self.list(path="/snippets/public", **kwargs)
+
+    @cli.register_custom_action(cls_names="SnippetManager")
+    def list_all(self, **kwargs: Any) -> Union[RESTObjectList, List[RESTObject]]:
+        """List all snippets.
+
+        Args:
+            get_all: If True, return all the items, without pagination
+            per_page: Number of items to retrieve per request
+            page: ID of the page to return (starts with page 1)
+            iterator: If set to True and no pagination option is
+                defined, return a generator instead of a list
             **kwargs: Extra options to send to the server (e.g. sudo)
 
         Raises:
@@ -90,6 +127,32 @@ class SnippetManager(CRUDMixin, RESTManager):
         Returns:
             A generator for the snippets list
         """
+        return self.list(path="/snippets/all", **kwargs)
+
+    def public(self, **kwargs: Any) -> Union[RESTObjectList, List[RESTObject]]:
+        """List all public snippets.
+
+        Args:
+            get_all: If True, return all the items, without pagination
+            per_page: Number of items to retrieve per request
+            page: ID of the page to return (starts with page 1)
+            iterator: If set to True and no pagination option is
+                defined, return a generator instead of a list
+            **kwargs: Extra options to send to the server (e.g. sudo)
+
+        Raises:
+            GitlabListError: If the list could not be retrieved
+
+        Returns:
+            The list of snippets, or a generator if `iterator` is True
+        """
+        utils.warn(
+            message=(
+                "Gitlab.snippets.public() is deprecated and will be removed in a"
+                "future major version. Use Gitlab.snippets.list_public() instead."
+            ),
+            category=DeprecationWarning,
+        )
         return self.list(path="/snippets/public", **kwargs)
 
     def get(self, id: Union[str, int], lazy: bool = False, **kwargs: Any) -> Snippet:
@@ -104,7 +167,7 @@ class ProjectSnippet(UserAgentDetailMixin, SaveMixin, ObjectDeleteMixin, RESTObj
     discussions: ProjectSnippetDiscussionManager
     notes: ProjectSnippetNoteManager
 
-    @cli.register_custom_action("ProjectSnippet")
+    @cli.register_custom_action(cls_names="ProjectSnippet")
     @exc.on_http_error(exc.GitlabGetError)
     def content(
         self,
@@ -151,11 +214,22 @@ class ProjectSnippetManager(CRUDMixin, RESTManager):
     _obj_cls = ProjectSnippet
     _from_parent_attrs = {"project_id": "id"}
     _create_attrs = RequiredOptional(
-        required=("title", "file_name", "content", "visibility"),
-        optional=("description",),
+        required=("title", "visibility"),
+        exclusive=("files", "file_name"),
+        optional=(
+            "description",
+            "content",
+        ),
     )
     _update_attrs = RequiredOptional(
-        optional=("title", "file_name", "content", "visibility", "description"),
+        optional=(
+            "title",
+            "files",
+            "file_name",
+            "content",
+            "visibility",
+            "description",
+        ),
     )
 
     def get(
