@@ -1,9 +1,13 @@
+import datetime
+
+
 def test_project_deploy_tokens(gl, project):
+    today = datetime.date.today().isoformat()
     deploy_token = project.deploytokens.create(
         {
             "name": "foo",
             "username": "bar",
-            "expires_at": "2022-01-01",
+            "expires_at": today,
             "scopes": ["read_registry"],
         }
     )
@@ -12,13 +16,11 @@ def test_project_deploy_tokens(gl, project):
 
     deploy_token = project.deploytokens.get(deploy_token.id)
     assert deploy_token.name == "foo"
-    assert deploy_token.expires_at == "2022-01-01T00:00:00.000Z"
+    assert deploy_token.expires_at == f"{today}T00:00:00.000Z"
     assert deploy_token.scopes == ["read_registry"]
     assert deploy_token.username == "bar"
 
     deploy_token.delete()
-    assert deploy_token not in project.deploytokens.list()
-    assert deploy_token not in gl.deploytokens.list()
 
 
 def test_group_deploy_tokens(gl, group):
@@ -37,5 +39,3 @@ def test_group_deploy_tokens(gl, group):
     assert deploy_token.scopes == ["read_registry"]
 
     deploy_token.delete()
-    assert deploy_token not in group.deploytokens.list()
-    assert deploy_token not in gl.deploytokens.list()
