@@ -1,3 +1,5 @@
+import time
+
 import pytest
 
 import gitlab
@@ -27,9 +29,10 @@ def test_save_after_lazy_get_with_path(project, lazy_project):
     assert lazy_project.description == "A new description"
 
 
-def test_delete_after_lazy_get_with_path(gl, group, wait_for_sidekiq):
+def test_delete_after_lazy_get_with_path(gl, group):
     project = gl.projects.create({"name": "lazy_project", "namespace_id": group.id})
-    wait_for_sidekiq(timeout=60)
+    # Pause to let GL catch up (happens on hosted too, sometimes takes a while for server to be ready to merge)
+    time.sleep(5)
     lazy_project = gl.projects.get(project.path_with_namespace, lazy=True)
     lazy_project.delete()
 
