@@ -1,3 +1,4 @@
+import time
 import uuid
 
 import pytest
@@ -45,7 +46,6 @@ def test_project_members(user, project):
     assert member.access_level == 30
 
     member.delete()
-    assert member not in project.members.list()
 
 
 def test_project_badges(project):
@@ -62,7 +62,6 @@ def test_project_badges(project):
     assert badge.image_url == "http://another.example.com"
 
     badge.delete()
-    assert badge not in project.badges.list()
 
 
 @pytest.mark.skip(reason="Commented out in legacy test")
@@ -78,7 +77,6 @@ def test_project_boards(project):
     last_list.save()
 
     last_list.delete()
-    assert last_list not in board.lists.list()
 
 
 def test_project_custom_attributes(gl, project):
@@ -97,7 +95,6 @@ def test_project_custom_attributes(gl, project):
     assert attr in project.customattributes.list()
 
     attr.delete()
-    assert attr not in project.customattributes.list()
 
 
 def test_project_environments(project):
@@ -115,8 +112,8 @@ def test_project_environments(project):
     assert environment.external_url == "http://new.env/whatever"
 
     environment.stop()
+
     environment.delete()
-    assert environment not in project.environments.list()
 
 
 def test_project_events(project):
@@ -156,7 +153,6 @@ def test_project_hooks(project):
     assert hook.note_events is True
 
     hook.delete()
-    assert hook not in project.hooks.list()
 
 
 def test_project_housekeeping(project):
@@ -184,7 +180,6 @@ def test_project_labels(project):
     assert label.subscribed is False
 
     label.delete()
-    assert label not in project.labels.list()
 
 
 def test_project_label_promotion(gl, group):
@@ -206,7 +201,6 @@ def test_project_label_promotion(gl, group):
     assert any(label.name == label_name for label in group.labels.list())
 
     group.labels.delete(label_name)
-    assert not any(label.name == label_name for label in group.labels.list())
 
 
 def test_project_milestones(project):
@@ -255,17 +249,36 @@ def test_project_pages_domains(gl, project):
     assert domain.domain == "foo.domain.com"
 
     domain.delete()
-    assert domain not in project.pagesdomains.list()
 
 
-def test_project_protected_branches(project):
-    p_b = project.protectedbranches.create({"name": "*-stable"})
+def test_project_protected_branches(project, gitlab_version):
+    # Updating a protected branch is possible from Gitlab 15.6
+    # https://docs.gitlab.com/ee/api/protected_branches.html#update-a-protected-branch
+    can_update_prot_branch = gitlab_version.major > 15 or (
+        gitlab_version.major == 15 and gitlab_version.minor >= 6
+    )
+
+    p_b = project.protectedbranches.create(
+        {
+            "name": "*-stable",
+            "allow_force_push": False,
+        }
+    )
     assert p_b.name == "*-stable"
+    assert not p_b.allow_force_push
     assert p_b in project.protectedbranches.list()
 
+    if can_update_prot_branch:
+        p_b.allow_force_push = True
+        p_b.save()
+        # Pause to let GL catch up (happens on hosted too, sometimes takes a while for server to be ready to merge)
+        time.sleep(5)
+
     p_b = project.protectedbranches.get("*-stable")
-    p_b.delete()
-    assert p_b not in project.protectedbranches.list()
+    if can_update_prot_branch:
+        assert p_b.allow_force_push
+
+        p_b.delete()
 
 
 def test_project_remote_mirrors(project):
@@ -300,9 +313,6 @@ def test_project_services(project):
 
     service.delete()
 
-    service = project.services.get("asana")
-    assert service.active is False
-
 
 def test_project_stars(project):
     project.star()
@@ -323,7 +333,6 @@ def test_project_tags(project, project_file):
     assert tag in project.tags.list()
 
     tag.delete()
-    assert tag not in project.tags.list()
 
 
 def test_project_triggers(project):
@@ -331,7 +340,6 @@ def test_project_triggers(project):
     assert trigger in project.triggers.list()
 
     trigger.delete()
-    assert trigger not in project.triggers.list()
 
 
 def test_project_wiki(project):
@@ -345,8 +353,8 @@ def test_project_wiki(project):
     # update and delete seem broken
     wiki.content = "new content"
     wiki.save()
+
     wiki.delete()
-    assert wiki not in project.wikis.list()
 
 
 def test_project_groups_list(gl, group):
