@@ -1,3 +1,5 @@
+import pytest
+
 import gitlab
 
 
@@ -20,10 +22,15 @@ def test_snippets(gl):
 
     content = snippet.content()
     assert content.decode() == "import gitlab"
-    assert snippet.user_agent_detail()["user_agent"]
+
+    all_snippets = gl.snippets.list_all(get_all=True)
+    public_snippets = gl.snippets.public(get_all=True)
+    list_public_snippets = gl.snippets.list_public(get_all=True)
+    assert isinstance(all_snippets, list)
+    assert isinstance(list_public_snippets, list)
+    assert public_snippets == list_public_snippets
 
     snippet.delete()
-    assert snippet not in gl.snippets.list(get_all=True)
 
 
 def test_project_snippets(project):
@@ -38,7 +45,16 @@ def test_project_snippets(project):
         }
     )
 
-    assert snippet.user_agent_detail()["user_agent"]
+    assert snippet.title == "snip1"
+
+
+@pytest.mark.xfail(reason="Returning 404 UserAgentDetail not found in GL 16")
+def test_project_snippet_user_agent_detail(project):
+    snippet = project.snippets.list()[0]
+
+    user_agent_detail = snippet.user_agent_detail()
+
+    assert user_agent_detail["user_agent"]
 
 
 def test_project_snippet_discussion(project):
@@ -56,8 +72,6 @@ def test_project_snippet_discussion(project):
     assert discussion.attributes["notes"][-1]["body"] == "updated body"
 
     note_from_get.delete()
-    discussion = snippet.discussions.get(discussion.id)
-    assert len(discussion.attributes["notes"]) == 1
 
 
 def test_project_snippet_file(project):
@@ -71,4 +85,3 @@ def test_project_snippet_file(project):
     assert snippet in project.snippets.list()
 
     snippet.delete()
-    assert snippet not in project.snippets.list()
