@@ -1,3 +1,6 @@
+import datetime
+
+
 def test_create_user_impersonation_token_with_scopes(gitlab_cli, user):
     cmd = [
         "user-impersonation-token",
@@ -8,6 +11,8 @@ def test_create_user_impersonation_token_with_scopes(gitlab_cli, user):
         "test-token",
         "--scopes",
         "api,read_user",
+        "--expires-at",
+        datetime.date.today().isoformat(),
     ]
     ret = gitlab_cli(cmd)
 
