@@ -1,4 +1,5 @@
 import pytest
+import responses
 
 import gitlab
 from tests.unit import helpers
@@ -59,6 +60,23 @@ def gl_retry():
     )
 
 
+@pytest.fixture
+def resp_get_current_user():
+    with responses.RequestsMock() as rsps:
+        rsps.add(
+            method=responses.GET,
+            url="http://localhost/api/v4/user",
+            json={
+                "id": 1,
+                "username": "username",
+                "web_url": "http://localhost/username",
+            },
+            content_type="application/json",
+            status=200,
+        )
+        yield rsps
+
+
 # Todo: parametrize, but check what tests it's really useful for
 @pytest.fixture
 def gl_trailing():
@@ -129,6 +147,12 @@ def user(gl):
     return gl.users.get(1, lazy=True)
 
 
+@pytest.fixture
+def current_user(gl, resp_get_current_user):
+    gl.auth()
+    return gl.user
+
+
 @pytest.fixture
 def migration(gl):
     return gl.bulk_imports.get(1, lazy=True)
