@@ -6,9 +6,43 @@ from typing import Optional
 import requests
 import responses
 
+from gitlab import base
+
 MATCH_EMPTY_QUERY_PARAMS = [responses.matchers.query_param_matcher({})]
 
 
+class FakeObject(base.RESTObject):
+    pass
+
+
+class FakeObjectWithoutId(base.RESTObject):
+    _id_attr = None
+
+
+class FakeObjectWithLongRepr(base.RESTObject):
+    _id_attr = None
+    _repr_attr = "test"
+
+
+class OtherFakeObject(FakeObject):
+    _id_attr = "foo"
+
+
+class FakeManager(base.RESTManager):
+    _path = "/tests"
+    _obj_cls = FakeObject
+
+
+class FakeParent(FakeObject):
+    id = 42
+
+
+class FakeManagerWithParent(base.RESTManager):
+    _path = "/tests/{test_id}/cases"
+    _obj_cls = FakeObject
+    _from_parent_attrs = {"test_id": "id"}
+
+
 # NOTE: The function `httmock_response` and the class `Headers` is taken from
 # https://github.com/patrys/httmock/ which is licensed under the Apache License, Version
 # 2.0. Thus it is allowed to be used in this project.
