@@ -361,13 +361,11 @@ def resp_share_project():
 
 
 @pytest.fixture
-def resp_unshare_project(no_content):
+def resp_unshare_project():
     with responses.RequestsMock() as rsps:
         rsps.add(
             method=responses.DELETE,
             url="http://localhost/api/v4/projects/1/share/1",
-            json=no_content,
-            content_type="application/json",
             status=204,
         )
         yield rsps
@@ -387,13 +385,11 @@ def resp_create_fork_relation():
 
 
 @pytest.fixture
-def resp_delete_fork_relation(no_content):
+def resp_delete_fork_relation():
     with responses.RequestsMock() as rsps:
         rsps.add(
             method=responses.DELETE,
             url="http://localhost/api/v4/projects/2/fork",
-            json=no_content,
-            content_type="application/json",
             status=204,
         )
         yield rsps
@@ -485,7 +481,7 @@ def resp_update_push_rules_project():
 
 
 @pytest.fixture
-def resp_delete_push_rules_project(no_content):
+def resp_delete_push_rules_project():
     with responses.RequestsMock() as rsps:
         rsps.add(
             method=responses.GET,
@@ -497,8 +493,6 @@ def resp_delete_push_rules_project(no_content):
         rsps.add(
             method=responses.DELETE,
             url="http://localhost/api/v4/projects/1/push_rule",
-            json=no_content,
-            content_type="application/json",
             status=204,
         )
         yield rsps
@@ -773,16 +767,6 @@ def test_transfer_project(project, resp_transfer_project):
     project.transfer("test-namespace")
 
 
-def test_artifact_project(project, resp_artifact):
-    with pytest.warns(DeprecationWarning):
-        project.artifact("ref_name", "artifact_path", "job")
-
-
-def test_transfer_project_deprecated_warns(project, resp_transfer_project):
-    with pytest.warns(DeprecationWarning):
-        project.transfer_project("test-namespace")
-
-
 def test_project_pull_mirror(project, resp_start_pull_mirroring_project):
     project.mirror_pull()
 
